@@ -621,6 +621,17 @@ our @TEST = (
             return [ 200, [ "Content-Type", "text/plain" ], [ "Foo: Bar\r\n\r\nHello World" ] ];
         },
     ],
+    [
+        'newlines',
+        sub {
+            my $cb = shift;
+            my $res = $cb->(GET "http://127.0.0.1/");
+            is length($res->content), 7;
+        },
+        sub {
+            return [ 200, [ "Content-Type", "text/plain" ], [ "Bar\nBaz" ] ];
+        },
+    ],
     [
         'test 404',
         sub {
